==> snipe-it-7.0.13.zip: snipe-it-7.0.13/resources/lang/et-EE/mail.php <==
<?php

return [

    'Accessory_Checkin_Notification' => 'Tarvikud sisse võetud',
    'Accessory_Checkout_Notification' => 'Tarvik väljastatud',
    'Asset_Checkin_Notification' => 'Vara sissevõetud',
    'Asset_Checkout_Notification' => 'Vara väljastatud',
    'Confirm_Accessory_Checkin' => 'Tarviku vastuvõtmise kinnitus',
    'Confirm_Asset_Checkin' => 'Vara sissevõtmise kinnitus',
    'Confirm_accessory_delivery' => 'Tarvitu tarne kinnitus',
    'Confirm_asset_delivery' => 'Vara tarne kinnitus',
    'Confirm_consumable_delivery' => 'Kulumaterjalide kohaletoimetamise kinnitus',
    'Confirm_license_delivery' => 'Litsentsi tarne kinnitus',
    'Consumable_checkout_notification' => 'Kuluosa väljastatud',
    'Days' => 'Päeva',
    'Expected_Checkin_Date' => 'Sulle väljastatud vahend tuleb tagastada :date',
    'Expected_Checkin_Notification' => 'Meeldetuletus: :name tagastamise tähtaeg läheneb',
    'Expected_Checkin_Report' => 'Eeldatav vahendite tagastamise aruanne',
    'Expiring_Assets_Report' => 'Aeguvate varade aruanne.',
    'Expiring_Licenses_Report' => 'Aeguvad litsentside aruanne.',
    'Item_Request_Canceled' => 'Üksuse taotlus tühistatud',
    'Item_Requested' => 'Taotletud üksus',
    'License_Checkin_Notification' => 'Litsents sisse võetud',
    'License_Checkout_Notification' => 'Litsents väljastatud',
    'Low_Inventory_Report' => 'Madal inventuuriaruanne',
    'a_user_canceled' => 'Kasutaja on tühistanud üksuse taotluse veebis',
    'a_user_requested' => 'Kasutaja on taotlenud üksuse veebis',
    'acceptance_asset_accepted' => 'Kasutaja aktsepteeris seadme',
    'acceptance_asset_declined' => 'Kasutaja keeldus seadmest',
    'accessory_name' => 'Tarviku Nimi',
    'additional_notes' => 'Lisamärkmed',
    'admin_has_created' => 'Administraator on loonud konto teile: veebisaidil.',
    'asset' => 'Vahend',
    'asset_name' => 'Ressursi nimi',
    'asset_requested' => 'Taotletud vahend',
    'asset_tag' => 'Varade silt',
    'assets_warrantee_alert' => 'Sul on :count vahend, mille garantii aegub järgmise :threshold päeva jooksul.|Sul on :count vahendit, mille garantii aegub järgmise :threshold päeva jooksul.',
    'assigned_to' => 'Määratud',
    'best_regards' => 'Parimate soovidega,',
    'canceled' => 'Tühistatud',
    'checkin_date' => 'Tagastamise kuupäev',
    'checkout_date' => 'Väljastamise kuupäev',
    'checkedout_from' => 'Väljastatud',
    'checkedin_from'  => 'Vastu võetud',
    'checked_into' => 'Väljastatud',
    'click_on_the_link_accessory' => 'Klõpsake allosas oleval lingil, et kinnitada, et olete lisaseadme kätte saanud.',
    'click_on_the_link_asset' => 'Klõpsake allosas oleval lingil, et kinnitada, et olete vara vastu võtnud.',
    'click_to_confirm' => 'Kinnitamiseks klõpsake järgmisel lingil: veebikonto:',
    'current_QTY' => 'Praegune QTY',
    'days' => 'päeva',
    'expecting_checkin_date' => 'Eeldatav tagastamise kuupäev',
    'expires' => 'Aegub',
    'hello' => 'Tere',
    'hi' => 'Tere',
    'i_have_read' => 'Olen lugenud ja nõustun kasutustingimustega ja saanud selle kirje.',
    'inventory_report' => 'Inventari aruanne',
    'item' => 'Kirje',
    'item_checked_reminder' => 'This is a reminder that you currently have :count items checked out to you that you have not accepted or declined. Please click the link below to confirm your decision.',
    'license_expiring_alert' => ':count litsents aegub järgmise :threshold päeva jooksul.|:count litsentsi aegub järgmise :threshold päeva jooksul.',
    'link_to_update_password' => 'Klienditeenuse uuendamiseks klõpsake järgmisel lingil:',
    'login' => 'Logi sisse:',
    'login_first_admin' => 'Logige oma uude Snipe-IT-seadmesse sisse, kasutades allpool toodud mandaate.',
    'low_inventory_alert' => ':count üksus on laos alla miinimummäära või saab varsti otsa.|:count üksust on laos alla miinimummäära või saab varsti otsa.',
    'min_QTY' => 'Min QTY',
    'name' => 'Nimi',
    'new_item_checked' => 'Uus vara on Teie nimele väljastatud, üksikasjad on allpool.',
    'notes' => 'Märkused',
    'password' => 'Parool',
    'password_reset' => 'Parooli taastamine',
    'read_the_terms' => 'Palun lugege allpool toodud kasutustingimusi.',
    'read_the_terms_and_click' => 'Palun lugege läbi allpool toodud kasutustingimused ja klõpsake alloleval lingil kinnitamiseks, et lugesite läbi ja nõustute kasutustingimustega, ning olete vara kätte saanud.',
    'requested' => 'Taotletud',
    'reset_link' => 'Teie salasõna lähtestamise link',
    'reset_password' => 'Parooli lähtestamiseks klõpsake siin:',
    'rights_reserved' => 'Kõik õigused kaitstud.',
    'serial' => 'Seerianumber',
    'snipe_webhook_test' => 'Snipe-IT Integratsiooni test',
    'snipe_webhook_summary' => 'Snipe-IT Integratsiooni testi kokkuvõte',
    'supplier' => 'Tarnija',
    'tag' => 'Silt',
    'test_email' => 'Test Snipe-IT-i e-posti teel',
    'test_mail_text' => 'See on Snipe-IT-i varahaldussüsteemi test. Kui sul on see, töötab post. :)',
    'the_following_item' => 'Järgmine vara on kontrollitud: ',
    'to_reset' => 'Selleks, et lähtestada oma :web parool, täitke see vorm:',
    'type' => 'Tüüp',
    'upcoming-audits' => 'Sul on :count vahend, mida tuleb auditeerida :threshold päeva jooksul.|Sul on :count vahendit, mida tuleb auditeerida :threshold päeva jooksul.',
    'user' => 'Kasutaja',
    'username' => 'Kasutajanimi',
    'unaccepted_asset_reminder' => 'You have Unaccepted Assets.',
    'welcome' => 'Tere tulemast, :name',
    'welcome_to' => 'Teretulemast lehele :web!',
    'your_assets' => 'Vaata oma varasi',
    'your_credentials' => 'Sinu Snipe-IT rekvisiidid',
    'mail_sent' => 'Mail sent successfully!',
];

==> snipe-it-7.1.17.zip: snipe-it-7.1.17/resources/lang/et-EE/mail.php <==
<?php

return [

    'Accessory_Checkin_Notification' => 'Tarvikud sisse võetud',
    'Accessory_Checkout_Notification' => 'Tarvik väljastatud',
    'Asset_Checkin_Notification' => 'Vara sissevõetud',
    'Asset_Checkout_Notification' => 'Vara väljastatud',
    'Confirm_Accessory_Checkin' => 'Tarviku vastuvõtmise kinnitus',
    'Confirm_Asset_Checkin' => 'Vara sissevõtmise kinnitus',
    'Confirm_accessory_delivery' => 'Tarvitu tarne kinnitus',
    'Confirm_asset_delivery' => 'Vara tarne kinnitus',
    'Confirm_consumable_delivery' => 'Kulumaterjalide kohaletoimetamise kinnitus',
    'Confirm_license_delivery' => 'Litsentsi tarne kinnitus',
    'Consumable_checkout_notification' => 'Kuluosa väljastatud',
    'Days' => 'Päeva',
    'Expected_Checkin_Date' => 'Sulle väljastatud vahend tuleb tagastada :date',
    'Expected_Checkin_Notification' => 'Meeldetuletus: :name tagastamise tähtaeg läheneb',
    'Expected_Checkin_Report' => 'Eeldatav vahendite tagastamise aruanne',
    'Expiring_Assets_Report' => 'Aeguvate varade aruanne.',
    'Expiring_Licenses_Report' => 'Aeguvad litsentside aruanne.',
    'Item_Request_Canceled' => 'Üksuse taotlus tühistatud',
    'Item_Requested' => 'Taotletud üksus',
    'License_Checkin_Notification' => 'Litsents sisse võetud',
    'License_Checkout_Notification' => 'Litsents väljastatud',
    'license_for'   => 'License for',
    'Low_Inventory_Report' => 'Madal inventuuriaruanne',
    'a_user_canceled' => 'Kasutaja on tühistanud üksuse taotluse veebis',
    'a_user_requested' => 'Kasutaja on taotlenud üksuse veebis',
    'acceptance_asset_accepted' => 'Kasutaja aktsepteeris seadme',
    'acceptance_asset_declined' => 'Kasutaja keeldus seadmest',
    'accessory_name' => 'Tarviku Nimi',
    'additional_notes' => 'Lisamärkmed',
    'admin_has_created' => 'Administraator on loonud konto teile: veebisaidil.',
    'asset' => 'Vahend',
    'asset_name' => 'Ressursi nimi',
    'asset_requested' => 'Taotletud vahend',
    'asset_tag' => 'Varade silt',
    'assets_warrantee_alert' => 'Sul on :count vahend, mille garantii aegub järgmise :threshold päeva jooksul.|Sul on :count vahendit, mille garantii aegub järgmise :threshold päeva jooksul.',
    'assigned_to' => 'Määratud',
    'best_regards' => 'Parimate soovidega,',
    'canceled' => 'Tühistatud',
    'checkin_date' => 'Tagastamise kuupäev',
    'checkout_date' => 'Väljastamise kuupäev',
    'checkedout_from' => 'Väljastatud',
    'checkedin_from'  => 'Vastu võetud',
    'checked_into' => 'Väljastatud',
    'click_on_the_link_accessory' => 'Klõpsake allosas oleval lingil, et kinnitada, et olete lisaseadme kätte saanud.',
    'click_on_the_link_asset' => 'Klõpsake allosas oleval lingil, et kinnitada, et olete vara vastu võtnud.',
    'click_to_confirm' => 'Kinnitamiseks klõpsake järgmisel lingil: veebikonto:',
    'current_QTY' => 'Praegune QTY',
    'days' => 'päeva',
    'expecting_checkin_date' => 'Eeldatav tagastamise kuupäev',
    'expires' => 'Aegub',
    'hello' => 'Tere',
    'hi' => 'Tere',
    'i_have_read' => 'Olen lugenud ja nõustun kasutustingimustega ja saanud selle vara.',
    'inventory_report' => 'Inventari aruanne',
    'item' => 'Vara',
    'item_checked_reminder' => 'This is a reminder that you currently have :count items checked out to you that you have not accepted or declined. Please click the link below to confirm your decision.',
    'license_expiring_alert' => ':count litsents aegub järgmise :threshold päeva jooksul.|:count litsentsi aegub järgmise :threshold päeva jooksul.',
    'link_to_update_password' => 'Klienditeenuse uuendamiseks klõpsake järgmisel lingil:',
    'login' => 'Logi sisse',
    'login_first_admin' => 'Logige oma uude Snipe-IT-seadmesse sisse, kasutades allpool toodud mandaate.',
    'low_inventory_alert' => ':count üksus on laos alla miinimummäära või saab varsti otsa.|:count üksust on laos alla miinimummäära või saab varsti otsa.',
    'min_QTY' => 'Min QTY',
    'name' => 'Nimi',
    'new_item_checked' => 'Uus vara on Teie nimele väljastatud, üksikasjad on allpool.',
    'notes' => 'Märkused',
    'password' => 'Parool',
    'password_reset' => 'Parooli taastamine',
    'read_the_terms' => 'Palun lugege allpool toodud kasutustingimusi.',
    'read_the_terms_and_click' => 'Palun lugege läbi allpool toodud kasutustingimused ja klõpsake alloleval lingil kinnitamiseks, et lugesite läbi ja nõustute kasutustingimustega, ning olete vara kätte saanud.',
    'requested' => 'Taotletud',
    'reset_link' => 'Teie salasõna lähtestamise link',
    'reset_password' => 'Parooli lähtestamiseks klõpsake siin:',
    'rights_reserved' => 'Kõik õigused kaitstud.',
    'serial' => 'Seerianumber',
    'snipe_webhook_test' => 'Snipe-IT Integratsiooni test',
    'snipe_webhook_summary' => 'Snipe-IT Integratsiooni testi kokkuvõte',
    'supplier' => 'Tarnija',
    'tag' => 'Silt',
    'test_email' => 'Test Snipe-IT-i e-posti teel',
    'test_mail_text' => 'See on Snipe-IT-i varahaldussüsteemi test. Kui sul on see, töötab post. :)',
    'the_following_item' => 'Järgmine vara on kontrollitud: ',
    'to_reset' => 'Selleks, et lähtestada oma :web parool, täitke see vorm:',
    'type' => 'Tüüp',
    'upcoming-audits' => 'Sul on :count vahend, mida tuleb auditeerida :threshold päeva jooksul.|Sul on :count vahendit, mida tuleb auditeerida :threshold päeva jooksul.',
    'user' => 'Kasutaja',
    'username' => 'Kasutajanimi',
    'unaccepted_asset_reminder' => 'You have Unaccepted Assets.',
    'welcome' => 'Tere tulemast, :name',
    'welcome_to' => 'Teretulemast lehele :web!',
    'your_assets' => 'Vaata oma varasi',
    'your_credentials' => 'Sinu Snipe-IT rekvisiidid',
    'mail_sent' => 'Mail sent successfully!',
];
